@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
+"""Jsonmodels."""
 
 __author__ = 'Szczepan Cieślik'
 __email__ = 'szczepan.cieslik@gmail.com'
-__version__ = '1.0.5'
+__version__ = '1.1'
